@@ -1,5 +1,6 @@
 use crate::{ProfileIdentifier, SecureChannelTrustInfo, TrustPolicy};
 use ockam_core::Result;
+use ockam_core::{async_trait, compat::boxed::Box};
 
 #[derive(Clone)]
 pub struct TrustIdentifierPolicy {
@@ -12,8 +13,9 @@ impl TrustIdentifierPolicy {
     }
 }
 
+#[async_trait]
 impl TrustPolicy for TrustIdentifierPolicy {
-    fn check(&self, trust_info: &SecureChannelTrustInfo) -> Result<bool> {
+    async fn check(&self, trust_info: &SecureChannelTrustInfo) -> Result<bool> {
         Ok(trust_info.their_profile_id == self.their_profile_id)
     }
 }
