@@ -6,15 +6,15 @@ pub enum EntityError {
     InvalidProof,
     ConsistencyError,
     ComplexEventsAreNotSupported,
-    EventIdDoesntMatch,
-    ProfileIdDoesntMatch,
+    EventIdDoesNotMatch,
+    ProfileIdDoesNotMatch,
     EmptyChange,
     ContactNotFound,
     EventNotFound,
     InvalidChainSequence,
     InvalidEventId,
-    AttestationRequesterDoesntMatch,
-    AttestationNonceDoesntMatch,
+    AttestationRequesterDoesNotMatch,
+    AttestationNonceDoesNotMatch,
     InvalidHubResponse,
     InvalidParameter,
     SecureChannelVerificationFailed,
@@ -34,7 +34,7 @@ pub enum EntityError {
     CredentialNotFound,
     InvalidIssueState,
     CredentialTrustCheckFailed,
-    SchemaIdDoesntMatch,
+    SchemaIdDoesNotMatch,
     IssuerListenerInvalidMessage,
     HolderInvalidMessage,
     IssuerInvalidMessage,
