@@ -75,7 +75,7 @@ impl CreateKeyChange {
 
 impl ProfileState {
     /// Create a new key
-    pub fn create_key_static(
+    pub async fn create_key_static(
         prev_id: EventIdentifier,
         key_attributes: KeyAttributes,
         attributes: ProfileEventAttributes,
@@ -107,13 +107,13 @@ impl ProfileState {
             }
         };
 
-        let secret_key = vault.secret_generate(secret_attributes)?;
-        let public_key = vault.secret_public_key_get(&secret_key)?;
+        let secret_key = vault.secret_generate(secret_attributes).await?;
+        let public_key = vault.secret_public_key_get(&secret_key).await?;
 
         let data = CreateKeyChangeData::new(key_attributes, public_key.as_ref().to_vec());
         let data_binary = data.encode().map_err(|_| EntityError::BareError)?;
-        let data_hash = vault.sha256(data_binary.as_slice())?;
-        let self_signature = vault.sign(&secret_key, &data_hash)?;
+        let data_hash = vault.sha256(data_binary.as_slice()).await?;
+        let self_signature = vault.sign(&secret_key, &data_hash).await?;
         let change = CreateKeyChange::new(data, self_signature);
 
         let profile_change = ProfileChange::new(
@@ -125,7 +125,7 @@ impl ProfileState {
         let changes = ChangeSet::new(prev_id, vec![profile_change]);
         let changes_binary = changes.encode().map_err(|_| EntityError::BareError)?;
 
-        let event_id = vault.sha256(&changes_binary)?;
+        let event_id = vault.sha256(&changes_binary).await?;
         let event_id = EventIdentifier::from_hash(event_id);
 
         // If we have root_key passed we should sign using it
@@ -137,7 +137,7 @@ impl ProfileState {
             sign_key = &secret_key;
         }
 
-        let signature = vault.sign(sign_key, event_id.as_ref())?;
+        let signature = vault.sign(sign_key, event_id.as_ref()).await?;
 
         let proof =
             ProfileChangeProof::Signature(Signature::new(SignatureType::RootSign, signature));
@@ -147,7 +147,7 @@ impl ProfileState {
     }
 
     /// Create a new key
-    pub(crate) fn create_key(
+    pub(crate) async fn create_key(
         &mut self,
         key_attributes: KeyAttributes,
         attributes: ProfileEventAttributes,
@@ -164,10 +164,10 @@ impl ProfileState {
 
         let prev_id = match self.change_history().get_last_event_id() {
             Ok(prev_id) => prev_id,
-            Err(_) => EventIdentifier::initial(self.vault()),
+            Err(_) => EventIdentifier::initial(&mut self.vault).await,
         };
 
-        let root_secret = self.get_root_secret().expect("can't get root secret");
+        let root_secret = self.get_root_secret().await.expect("can't get root secret");
         let root_key = Some(&root_secret);
 
         Self::create_key_static(
@@ -175,7 +175,8 @@ impl ProfileState {
             key_attributes,
             attributes,
             root_key,
-            &mut self.vault(),
+            &mut self.vault,
         )
+        .await
     }
 }
